==> topia-it-3.1.3.2-sources.jar: org/nuiton/topia/it/mapping/TopiaItMappingTopiaDaoSupplier.java <==
package org.nuiton.topia.it.mapping;

import javax.annotation.Generated;
import org.nuiton.topia.it.mapping.test1.A11TopiaDao;
import org.nuiton.topia.it.mapping.test1.A12TopiaDao;
import org.nuiton.topia.it.mapping.test1.A13TopiaDao;
import org.nuiton.topia.it.mapping.test1.A1TopiaDao;
import org.nuiton.topia.it.mapping.test1.B11TopiaDao;
import org.nuiton.topia.it.mapping.test1.B12TopiaDao;
import org.nuiton.topia.it.mapping.test1.B13TopiaDao;
import org.nuiton.topia.it.mapping.test1.B1TopiaDao;
import org.nuiton.topia.it.mapping.test11.A11ATopiaDao;
import org.nuiton.topia.it.mapping.test11.A11BTopiaDao;
import org.nuiton.topia.it.mapping.test11.A11CTopiaDao;
import org.nuiton.topia.it.mapping.test11.A11DTopiaDao;
import org.nuiton.topia.it.mapping.test11.A11ETopiaDao;
import org.nuiton.topia.it.mapping.test11.B11ATopiaDao;
import org.nuiton.topia.it.mapping.test11.B11BTopiaDao;
import org.nuiton.topia.it.mapping.test11.B11CTopiaDao;
import org.nuiton.topia.it.mapping.test11.B11DTopiaDao;
import org.nuiton.topia.it.mapping.test12.A12ATopiaDao;
import org.nuiton.topia.it.mapping.test13.A13ATopiaDao;
import org.nuiton.topia.it.mapping.test13.B13ATopiaDao;
import org.nuiton.topia.it.mapping.test13.B13BTopiaDao;
import org.nuiton.topia.it.mapping.test13.B13CTopiaDao;
import org.nuiton.topia.it.mapping.test14.A14ATopiaDao;
import org.nuiton.topia.it.mapping.test14.A14BTopiaDao;
import org.nuiton.topia.it.mapping.test14.A14CTopiaDao;
import org.nuiton.topia.it.mapping.test14.A14DTopiaDao;
import org.nuiton.topia.it.mapping.test14.Assoc14ATopiaDao;
import org.nuiton.topia.it.mapping.test14.Assoc14BTopiaDao;
import org.nuiton.topia.it.mapping.test14.Assoc14CTopiaDao;
import org.nuiton.topia.it.mapping.test14.Assoc14DTopiaDao;
import org.nuiton.topia.it.mapping.test14.B14ATopiaDao;
import org.nuiton.topia.it.mapping.test14.B14BTopiaDao;
import org.nuiton.topia.it.mapping.test14.B14CTopiaDao;
import org.nuiton.topia.it.mapping.test14.B14DTopiaDao;
import org.nuiton.topia.it.mapping.test15.A15ATopiaDao;
import org.nuiton.topia.it.mapping.test16.A16TopiaDao;
import org.nuiton.topia.it.mapping.test16.B16TopiaDao;
import org.nuiton.topia.it.mapping.test16.C16TopiaDao;
import org.nuiton.topia.it.mapping.test17.A17TopiaDao;
import org.nuiton.topia.it.mapping.test17.B17TopiaDao;
import org.nuiton.topia.it.mapping.test17.BB17TopiaDao;
import org.nuiton.topia.it.mapping.test18.A18TopiaDao;
import org.nuiton.topia.it.mapping.test18.B18TopiaDao;
import org.nuiton.topia.it.mapping.test2.A21TopiaDao;
import org.nuiton.topia.it.mapping.test2.A22TopiaDao;
import org.nuiton.topia.it.mapping.test2.A23TopiaDao;
import org.nuiton.topia.it.mapping.test2.A2TopiaDao;
import org.nuiton.topia.it.mapping.test2.B21TopiaDao;
import org.nuiton.topia.it.mapping.test2.B22TopiaDao;
import org.nuiton.topia.it.mapping.test2.B23TopiaDao;
import org.nuiton.topia.it.mapping.test2.B2TopiaDao;
import org.nuiton.topia.it.mapping.test3.A31TopiaDao;
import org.nuiton.topia.it.mapping.test3.A32TopiaDao;
import org.nuiton.topia.it.mapping.test3.A33TopiaDao;
import org.nuiton.topia.it.mapping.test3.A3TopiaDao;
import org.nuiton.topia.it.mapping.test3.B31TopiaDao;
import org.nuiton.topia.it.mapping.test3.B32TopiaDao;
import org.nuiton.topia.it.mapping.test3.B33TopiaDao;
import org.nuiton.topia.it.mapping.test3.B3TopiaDao;
import org.nuiton.topia.it.mapping.test4.A4TopiaDao;
import org.nuiton.topia.it.mapping.test5.A51TopiaDao;
import org.nuiton.topia.it.mapping.test5.A53TopiaDao;
import org.nuiton.topia.it.mapping.test5.A5TopiaDao;
import org.nuiton.topia.it.mapping.test5.B51TopiaDao;
import org.nuiton.topia.it.mapping.test5.B53TopiaDao;
import org.nuiton.topia.it.mapping.test5.B5TopiaDao;
import org.nuiton.topia.it.mapping.test6.A61TopiaDao;
import org.nuiton.topia.it.mapping.test6.A62TopiaDao;
import org.nuiton.topia.it.mapping.test6.A63TopiaDao;
import org.nuiton.topia.it.mapping.test6.A6TopiaDao;
import org.nuiton.topia.it.mapping.test6.B61TopiaDao;
import org.nuiton.topia.it.mapping.test6.B62TopiaDao;
import org.nuiton.topia.it.mapping.test6.B63TopiaDao;
import org.nuiton.topia.it.mapping.test6.B6TopiaDao;
import org.nuiton.topia.it.mapping.test7.A71TopiaDao;
import org.nuiton.topia.it.mapping.test7.A72TopiaDao;
import org.nuiton.topia.it.mapping.test7.A73TopiaDao;
import org.nuiton.topia.it.mapping.test7.A7TopiaDao;
import org.nuiton.topia.it.mapping.test7.B71TopiaDao;
import org.nuiton.topia.it.mapping.test7.B72TopiaDao;
import org.nuiton.topia.it.mapping.test7.B73TopiaDao;
import org.nuiton.topia.it.mapping.test7.B7TopiaDao;
import org.nuiton.topia.it.mapping.test9.A9TopiaDao;
import org.nuiton.topia.persistence.TopiaDaoSupplier;

@Generated(value = "org.nuiton.topia.templates.PersistenceContextTransformer", date = "Tue Oct 18 14:08:27 CEST 2016")
public interface TopiaItMappingTopiaDaoSupplier extends TopiaDaoSupplier {

    A1TopiaDao getA1Dao();

    A11TopiaDao getA11Dao();

    A12TopiaDao getA12Dao();

    A13TopiaDao getA13Dao();

    B1TopiaDao getB1Dao();

    B11TopiaDao getB11Dao();

    B12TopiaDao getB12Dao();

    B13TopiaDao getB13Dao();

    A11ATopiaDao getA11ADao();

    A11BTopiaDao getA11BDao();

    A11CTopiaDao getA11CDao();

    A11DTopiaDao getA11DDao();

    A11ETopiaDao getA11EDao();

    B11ATopiaDao getB11ADao();

    B11BTopiaDao getB11BDao();

    B11CTopiaDao getB11CDao();

    B11DTopiaDao getB11DDao();

    A12ATopiaDao getA12ADao();

    A13ATopiaDao getA13ADao();

    B13ATopiaDao getB13ADao();

    B13BTopiaDao getB13BDao();

    B13CTopiaDao getB13CDao();

    A14ATopiaDao getA14ADao();

    A14BTopiaDao getA14BDao();

    A14CTopiaDao getA14CDao();

    A14DTopiaDao getA14DDao();

    Assoc14ATopiaDao getAssoc14ADao();

    Assoc14BTopiaDao getAssoc14BDao();

    Assoc14CTopiaDao getAssoc14CDao();

    Assoc14DTopiaDao getAssoc14DDao();

    B14ATopiaDao getB14ADao();

    B14BTopiaDao getB14BDao();

    B14CTopiaDao getB14CDao();

    B14DTopiaDao getB14DDao();

    A15ATopiaDao getA15ADao();

    A16TopiaDao getA16Dao();

    B16TopiaDao getB16Dao();

    C16TopiaDao getC16Dao();

    A17TopiaDao getA17Dao();

    B17TopiaDao getB17Dao();

    BB17TopiaDao getBB17Dao();

    A18TopiaDao getA18Dao();

    B18TopiaDao getB18Dao();

    A2TopiaDao getA2Dao();

    A21TopiaDao getA21Dao();

    A22TopiaDao getA22Dao();

    A23TopiaDao getA23Dao();

    B2TopiaDao getB2Dao();

    B21TopiaDao getB21Dao();

    B22TopiaDao getB22Dao();

    B23TopiaDao getB23Dao();

    A3TopiaDao getA3Dao();

    A31TopiaDao getA31Dao();

    A32TopiaDao getA32Dao();

    A33TopiaDao getA33Dao();

    B3TopiaDao getB3Dao();

    B31TopiaDao getB31Dao();

    B32TopiaDao getB32Dao();

    B33TopiaDao getB33Dao();

    A4TopiaDao getA4Dao();

    A5TopiaDao getA5Dao();

    A51TopiaDao getA51Dao();

    A53TopiaDao getA53Dao();

    B5TopiaDao getB5Dao();

    B51TopiaDao getB51Dao();

    B53TopiaDao getB53Dao();

    A6TopiaDao getA6Dao();

    A61TopiaDao getA61Dao();

    A62TopiaDao getA62Dao();

    A63TopiaDao getA63Dao();

    B6TopiaDao getB6Dao();

    B61TopiaDao getB61Dao();

    B62TopiaDao getB62Dao();

    B63TopiaDao getB63Dao();

    A7TopiaDao getA7Dao();

    A71TopiaDao getA71Dao();

    A72TopiaDao getA72Dao();

    A73TopiaDao getA73Dao();

    B7TopiaDao getB7Dao();

    B71TopiaDao getB71Dao();

    B72TopiaDao getB72Dao();

    B73TopiaDao getB73Dao();

    A9TopiaDao getA9Dao();

} //TopiaItMappingTopiaDaoSupplier

==> topia-it-3.1.4-sources.jar: org/nuiton/topia/it/mapping/TopiaItMappingTopiaDaoSupplier.java <==
package org.nuiton.topia.it.mapping;

import javax.annotation.Generated;
import org.nuiton.topia.it.mapping.test1.A11TopiaDao;
import org.nuiton.topia.it.mapping.test1.A12TopiaDao;
import org.nuiton.topia.it.mapping.test1.A13TopiaDao;
import org.nuiton.topia.it.mapping.test1.A1TopiaDao;
import org.nuiton.topia.it.mapping.test1.B11TopiaDao;
import org.nuiton.topia.it.mapping.test1.B12TopiaDao;
import org.nuiton.topia.it.mapping.test1.B13TopiaDao;
import org.nuiton.topia.it.mapping.test1.B1TopiaDao;
import org.nuiton.topia.it.mapping.test11.A11ATopiaDao;
import org.nuiton.topia.it.mapping.test11.A11BTopiaDao;
import org.nuiton.topia.it.mapping.test11.A11CTopiaDao;
import org.nuiton.topia.it.mapping.test11.A11DTopiaDao;
import org.nuiton.topia.it.mapping.test11.A11ETopiaDao;
import org.nuiton.topia.it.mapping.test11.B11ATopiaDao;
import org.nuiton.topia.it.mapping.test11.B11BTopiaDao;
import org.nuiton.topia.it.mapping.test11.B11CTopiaDao;
import org.nuiton.topia.it.mapping.test11.B11DTopiaDao;
import org.nuiton.topia.it.mapping.test12.A12ATopiaDao;
import org.nuiton.topia.it.mapping.test13.A13ATopiaDao;
import org.nuiton.topia.it.mapping.test13.B13ATopiaDao;
import org.nuiton.topia.it.mapping.test13.B13BTopiaDao;
import org.nuiton.topia.it.mapping.test13.B13CTopiaDao;
import org.nuiton.topia.it.mapping.test14.A14ATopiaDao;
import org.nuiton.topia.it.mapping.test14.A14BTopiaDao;
import org.nuiton.topia.it.mapping.test14.A14CTopiaDao;
import org.nuiton.topia.it.mapping.test14.A14DTopiaDao;
import org.nuiton.topia.it.mapping.test14.Assoc14ATopiaDao;
import org.nuiton.topia.it.mapping.test14.Assoc14BTopiaDao;
import org.nuiton.topia.it.mapping.test14.Assoc14CTopiaDao;
import org.nuiton.topia.it.mapping.test14.Assoc14DTopiaDao;
import org.nuiton.topia.it.mapping.test14.B14ATopiaDao;
import org.nuiton.topia.it.mapping.test14.B14BTopiaDao;
import org.nuiton.topia.it.mapping.test14.B14CTopiaDao;
import org.nuiton.topia.it.mapping.test14.B14DTopiaDao;
import org.nuiton.topia.it.mapping.test15.A15ATopiaDao;
import org.nuiton.topia.it.mapping.test16.A16TopiaDao;
import org.nuiton.topia.it.mapping.test16.B16TopiaDao;
import org.nuiton.topia.it.mapping.test16.C16TopiaDao;
import org.nuiton.topia.it.mapping.test17.A17TopiaDao;
import org.nuiton.topia.it.mapping.test17.B17TopiaDao;
import org.nuiton.topia.it.mapping.test17.BB17TopiaDao;
import org.nuiton.topia.it.mapping.test18.A18TopiaDao;
import org.nuiton.topia.it.mapping.test18.B18TopiaDao;
import org.nuiton.topia.it.mapping.test2.A21TopiaDao;
import org.nuiton.topia.it.mapping.test2.A22TopiaDao;
import org.nuiton.topia.it.mapping.test2.A23TopiaDao;
import org.nuiton.topia.it.mapping.test2.A2TopiaDao;
import org.nuiton.topia.it.mapping.test2.B21TopiaDao;
import org.nuiton.topia.it.mapping.test2.B22TopiaDao;
import org.nuiton.topia.it.mapping.test2.B23TopiaDao;
import org.nuiton.topia.it.mapping.test2.B2TopiaDao;
import org.nuiton.topia.it.mapping.test3.A31TopiaDao;
import org.nuiton.topia.it.mapping.test3.A32TopiaDao;
import org.nuiton.topia.it.mapping.test3.A33TopiaDao;
import org.nuiton.topia.it.mapping.test3.A3TopiaDao;
import org.nuiton.topia.it.mapping.test3.B31TopiaDao;
import org.nuiton.topia.it.mapping.test3.B32TopiaDao;
import org.nuiton.topia.it.mapping.test3.B33TopiaDao;
import org.nuiton.topia.it.mapping.test3.B3TopiaDao;
import org.nuiton.topia.it.mapping.test4.A4TopiaDao;
import org.nuiton.topia.it.mapping.test5.A51TopiaDao;
import org.nuiton.topia.it.mapping.test5.A53TopiaDao;
import org.nuiton.topia.it.mapping.test5.A5TopiaDao;
import org.nuiton.topia.it.mapping.test5.B51TopiaDao;
import org.nuiton.topia.it.mapping.test5.B53TopiaDao;
import org.nuiton.topia.it.mapping.test5.B5TopiaDao;
import org.nuiton.topia.it.mapping.test6.A61TopiaDao;
import org.nuiton.topia.it.mapping.test6.A62TopiaDao;
import org.nuiton.topia.it.mapping.test6.A63TopiaDao;
import org.nuiton.topia.it.mapping.test6.A6TopiaDao;
import org.nuiton.topia.it.mapping.test6.B61TopiaDao;
import org.nuiton.topia.it.mapping.test6.B62TopiaDao;
import org.nuiton.topia.it.mapping.test6.B63TopiaDao;
import org.nuiton.topia.it.mapping.test6.B6TopiaDao;
import org.nuiton.topia.it.mapping.test7.A71TopiaDao;
import org.nuiton.topia.it.mapping.test7.A72TopiaDao;
import org.nuiton.topia.it.mapping.test7.A73TopiaDao;
import org.nuiton.topia.it.mapping.test7.A7TopiaDao;
import org.nuiton.topia.it.mapping.test7.B71TopiaDao;
import org.nuiton.topia.it.mapping.test7.B72TopiaDao;
import org.nuiton.topia.it.mapping.test7.B73TopiaDao;
import org.nuiton.topia.it.mapping.test7.B7TopiaDao;
import org.nuiton.topia.it.mapping.test9.A9TopiaDao;
import org.nuiton.topia.persistence.TopiaDaoSupplier;

@Generated(value = "org.nuiton.topia.templates.PersistenceContextTransformer", date = "Mon Dec 12 09:44:11 CET 2016")
public interface TopiaItMappingTopiaDaoSupplier extends TopiaDaoSupplier {

    A1TopiaDao getA1Dao();

    A11TopiaDao getA11Dao();

    A12TopiaDao getA12Dao();

    A13TopiaDao getA13Dao();

    B1TopiaDao getB1Dao();

    B11TopiaDao getB11Dao();

    B12TopiaDao getB12Dao();

    B13TopiaDao getB13Dao();

    A11ATopiaDao getA11ADao();

    A11BTopiaDao getA11BDao();

    A11CTopiaDao getA11CDao();

    A11DTopiaDao getA11DDao();

    A11ETopiaDao getA11EDao();

    B11ATopiaDao getB11ADao();

    B11BTopiaDao getB11BDao();

    B11CTopiaDao getB11CDao();

    B11DTopiaDao getB11DDao();

    A12ATopiaDao getA12ADao();

    A13ATopiaDao getA13ADao();

    B13ATopiaDao getB13ADao();

    B13BTopiaDao getB13BDao();

    B13CTopiaDao getB13CDao();

    A14ATopiaDao getA14ADao();

    A14BTopiaDao getA14BDao();

    A14CTopiaDao getA14CDao();

    A14DTopiaDao getA14DDao();

    Assoc14ATopiaDao getAssoc14ADao();

    Assoc14BTopiaDao getAssoc14BDao();

    Assoc14CTopiaDao getAssoc14CDao();

    Assoc14DTopiaDao getAssoc14DDao();

    B14ATopiaDao getB14ADao();

    B14BTopiaDao getB14BDao();

    B14CTopiaDao getB14CDao();

    B14DTopiaDao getB14DDao();

    A15ATopiaDao getA15ADao();

    A16TopiaDao getA16Dao();

    B16TopiaDao getB16Dao();

    C16TopiaDao getC16Dao();

    A17TopiaDao getA17Dao();

    B17TopiaDao getB17Dao();

    BB17TopiaDao getBB17Dao();

    A18TopiaDao getA18Dao();

    B18TopiaDao getB18Dao();

    A2TopiaDao getA2Dao();

    A21TopiaDao getA21Dao();

    A22TopiaDao getA22Dao();

    A23TopiaDao getA23Dao();

    B2TopiaDao getB2Dao();

    B21TopiaDao getB21Dao();

    B22TopiaDao getB22Dao();

    B23TopiaDao getB23Dao();

    A3TopiaDao getA3Dao();

    A31TopiaDao getA31Dao();

    A32TopiaDao getA32Dao();

    A33TopiaDao getA33Dao();

    B3TopiaDao getB3Dao();

    B31TopiaDao getB31Dao();

    B32TopiaDao getB32Dao();

    B33TopiaDao getB33Dao();

    A4TopiaDao getA4Dao();

    A5TopiaDao getA5Dao();

    A51TopiaDao getA51Dao();

    A53TopiaDao getA53Dao();

    B5TopiaDao getB5Dao();

    B51TopiaDao getB51Dao();

    B53TopiaDao getB53Dao();

    A6TopiaDao getA6Dao();

    A61TopiaDao getA61Dao();

    A62TopiaDao getA62Dao();

    A63TopiaDao getA63Dao();

    B6TopiaDao getB6Dao();

    B61TopiaDao getB61Dao();

    B62TopiaDao getB62Dao();

    B63TopiaDao getB63Dao();

    A7TopiaDao getA7Dao();

    A71TopiaDao getA71Dao();

    A72TopiaDao getA72Dao();

    A73TopiaDao getA73Dao();

    B7TopiaDao getB7Dao();

    B71TopiaDao getB71Dao();

    B72TopiaDao getB72Dao();

    B73TopiaDao getB73Dao();

    A9TopiaDao getA9Dao();

} //TopiaItMappingTopiaDaoSupplier
